summaryrefslogtreecommitdiffstats
path: root/include/cppuhelper/compbase1.hxx
diff options
context:
space:
mode:
authorNoel Grandin <noel@peralex.com>2015-10-20 11:02:14 +0200
committerNoel Grandin <noelgrandin@gmail.com>2015-10-21 06:36:39 +0000
commit08233bd25849cc7d5d092aa073362c7766cbcc19 (patch)
treeef27b8d8b00e531e31eea084f7cce81b6cb0bcb2 /include/cppuhelper/compbase1.hxx
parentcom::sun::star->css in include/cppu (diff)
downloadcore-08233bd25849cc7d5d092aa073362c7766cbcc19.tar.gz
core-08233bd25849cc7d5d092aa073362c7766cbcc19.zip
com::sun::star->css in include/cppuhelper
Change-Id: I3d9dcd4cd756a3f0d9cedd894377a117c9dbeecc Reviewed-on: https://gerrit.libreoffice.org/19486 Reviewed-by: Noel Grandin <noelgrandin@gmail.com> Tested-by: Noel Grandin <noelgrandin@gmail.com>
Diffstat (limited to 'include/cppuhelper/compbase1.hxx')
-rw-r--r--include/cppuhelper/compbase1.hxx44
1 files changed, 22 insertions, 22 deletions
diff --git a/include/cppuhelper/compbase1.hxx b/include/cppuhelper/compbase1.hxx
index b710eccb5cfe..998613d50f49 100644
--- a/include/cppuhelper/compbase1.hxx
+++ b/include/cppuhelper/compbase1.hxx
@@ -25,12 +25,12 @@
namespace cppu
{
- /** Implementation helper supporting com::sun::star::lang::XTypeProvider and
- com::sun::star::lang::XComponent.
+ /** Implementation helper supporting css::lang::XTypeProvider and
+ css::lang::XComponent.
Upon disposing objects of this class, sub-classes receive a disposing()
call. Objects of this class can be held weakly, i.e. by a
- com::sun::star::uno::WeakReference.
+ css::uno::WeakReference.
@attention
The life-cycle of the passed mutex reference has to be longer than objects of this class.
@@ -42,7 +42,7 @@ namespace cppu
template< class Ifc1 >
class SAL_NO_VTABLE SAL_DLLPUBLIC_TEMPLATE WeakComponentImplHelper1
: public WeakComponentImplHelperBase
- , public ::com::sun::star::lang::XTypeProvider
+ , public css::lang::XTypeProvider
, public Ifc1
{
struct cd : public rtl::StaticAggregate< class_data, ImplClassData1< Ifc1, WeakComponentImplHelper1< Ifc1 > > > {};
@@ -50,21 +50,21 @@ namespace cppu
inline WeakComponentImplHelper1( ::osl::Mutex & rMutex ) throw ()
: WeakComponentImplHelperBase( rMutex )
{}
- virtual ::com::sun::star::uno::Any SAL_CALL queryInterface( ::com::sun::star::uno::Type const & rType ) throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
+ virtual css::uno::Any SAL_CALL queryInterface( css::uno::Type const & rType ) throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return WeakComponentImplHelper_query( rType, cd::get(), this, static_cast<WeakComponentImplHelperBase *>(this) ); }
virtual void SAL_CALL acquire() throw () SAL_OVERRIDE
{ WeakComponentImplHelperBase::acquire(); }
virtual void SAL_CALL release() throw () SAL_OVERRIDE
{ WeakComponentImplHelperBase::release(); }
- virtual void SAL_CALL dispose()throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
+ virtual void SAL_CALL dispose()throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ WeakComponentImplHelperBase::dispose(); }
- virtual void SAL_CALL addEventListener(const ::com::sun::star::uno::Reference< ::com::sun::star::lang::XEventListener > & xListener)throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
+ virtual void SAL_CALL addEventListener(const css::uno::Reference< css::lang::XEventListener > & xListener)throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ WeakComponentImplHelperBase::addEventListener(xListener); }
- virtual void SAL_CALL removeEventListener(const ::com::sun::star::uno::Reference< ::com::sun::star::lang::XEventListener > & xListener)throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
+ virtual void SAL_CALL removeEventListener(const css::uno::Reference< css::lang::XEventListener > & xListener)throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ WeakComponentImplHelperBase::removeEventListener(xListener); }
- virtual ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Type > SAL_CALL getTypes() throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
+ virtual css::uno::Sequence< css::uno::Type > SAL_CALL getTypes() throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return WeakComponentImplHelper_getTypes( cd::get() ); }
- virtual ::com::sun::star::uno::Sequence< sal_Int8 > SAL_CALL getImplementationId() throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
+ virtual css::uno::Sequence< sal_Int8 > SAL_CALL getImplementationId() throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return ImplHelper_getImplementationId( cd::get() ); }
};
@@ -80,7 +80,7 @@ namespace cppu
template< class Ifc1 >
class SAL_NO_VTABLE SAL_DLLPUBLIC_TEMPLATE PartialWeakComponentImplHelper1
: public WeakComponentImplHelperBase
- , public ::com::sun::star::lang::XTypeProvider
+ , public css::lang::XTypeProvider
, public Ifc1
{
struct cd : public rtl::StaticAggregate< class_data, ImplClassData1< Ifc1, PartialWeakComponentImplHelper1< Ifc1 > > > {};
@@ -88,24 +88,24 @@ namespace cppu
inline PartialWeakComponentImplHelper1( ::osl::Mutex & rMutex ) throw ()
: WeakComponentImplHelperBase( rMutex )
{}
- virtual ::com::sun::star::uno::Any SAL_CALL queryInterface( ::com::sun::star::uno::Type const & rType ) throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
+ virtual css::uno::Any SAL_CALL queryInterface( css::uno::Type const & rType ) throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return WeakComponentImplHelper_query( rType, cd::get(), this, static_cast<WeakComponentImplHelperBase *>(this) ); }
virtual void SAL_CALL acquire() throw () SAL_OVERRIDE
{ WeakComponentImplHelperBase::acquire(); }
virtual void SAL_CALL release() throw () SAL_OVERRIDE
{ WeakComponentImplHelperBase::release(); }
- virtual ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Type > SAL_CALL getTypes() throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
+ virtual css::uno::Sequence< css::uno::Type > SAL_CALL getTypes() throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return WeakComponentImplHelper_getTypes( cd::get() ); }
- virtual ::com::sun::star::uno::Sequence< sal_Int8 > SAL_CALL getImplementationId() throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
+ virtual css::uno::Sequence< sal_Int8 > SAL_CALL getImplementationId() throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return ImplHelper_getImplementationId( cd::get() ); }
};
- /** Implementation helper supporting com::sun::star::lang::XTypeProvider and
- com::sun::star::lang::XComponent.
+ /** Implementation helper supporting css::lang::XTypeProvider and
+ css::lang::XComponent.
Upon disposing objects of this class, sub-classes receive a disposing()
call. Objects of this class can be held weakly, i.e. by a
- com::sun::star::uno::WeakReference. Object of this class can be
+ css::uno::WeakReference. Object of this class can be
aggregated, i.e. incoming queryInterface() calls are delegated.
@attention
@@ -120,7 +120,7 @@ namespace cppu
template< class Ifc1 >
class SAL_NO_VTABLE SAL_DLLPUBLIC_TEMPLATE WeakAggComponentImplHelper1
: public WeakAggComponentImplHelperBase
- , public ::com::sun::star::lang::XTypeProvider
+ , public css::lang::XTypeProvider
, public Ifc1
{
struct cd : public rtl::StaticAggregate< class_data, ImplClassData1< Ifc1, WeakAggComponentImplHelper1< Ifc1 > > > {};
@@ -128,17 +128,17 @@ namespace cppu
inline WeakAggComponentImplHelper1( ::osl::Mutex & rMutex ) throw ()
: WeakAggComponentImplHelperBase( rMutex )
{}
- virtual ::com::sun::star::uno::Any SAL_CALL queryInterface( ::com::sun::star::uno::Type const & rType ) throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
+ virtual css::uno::Any SAL_CALL queryInterface( css::uno::Type const & rType ) throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return WeakAggComponentImplHelperBase::queryInterface( rType ); }
- virtual ::com::sun::star::uno::Any SAL_CALL queryAggregation( ::com::sun::star::uno::Type const & rType ) throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
+ virtual css::uno::Any SAL_CALL queryAggregation( css::uno::Type const & rType ) throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return WeakAggComponentImplHelper_queryAgg( rType, cd::get(), this, static_cast<WeakAggComponentImplHelperBase *>(this) ); }
virtual void SAL_CALL acquire() throw () SAL_OVERRIDE
{ WeakAggComponentImplHelperBase::acquire(); }
virtual void SAL_CALL release() throw () SAL_OVERRIDE
{ WeakAggComponentImplHelperBase::release(); }
- virtual ::com::sun::star::uno::Sequence< ::com::sun::star::uno::Type > SAL_CALL getTypes() throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
+ virtual css::uno::Sequence< css::uno::Type > SAL_CALL getTypes() throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return WeakAggComponentImplHelper_getTypes( cd::get() ); }
- virtual ::com::sun::star::uno::Sequence< sal_Int8 > SAL_CALL getImplementationId() throw (::com::sun::star::uno::RuntimeException, std::exception) SAL_OVERRIDE
+ virtual css::uno::Sequence< sal_Int8 > SAL_CALL getImplementationId() throw (css::uno::RuntimeException, std::exception) SAL_OVERRIDE
{ return ImplHelper_getImplementationId( cd::get() ); }
};
}